!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_kij
!! NAME
!! calc_kij
!!
!! FUNCTION
!! Compute kij terms:
!!  kij=<phi_i|T|phi_j>-<tphi_i|T|tphi_j>
!!  where T is the kinetic operator
!!
!! COPYRIGHT
!! Copyright (C) 1998-2005 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  pawdata
!!    %indlmn(6,lmn_size)= Gives l,m,n,lm,ln,s for i=lmn
!!    %rad(max_meshsz)= Coordinates of the radial grid
!!  pawps
!!    %phi(sph_meshsz,basis_size)= PAW atomic wavefunctions on the radial grid
!!    %tphi(sph_meshsz,basis_size)= PAW atomic pseudo-wavefunctions on the radial grid
!!  pshead
!!    %basis_size= Number of elements for the paw nl basis
!!    %lmn_size= Number of elements for the paw basis
!!    %orbitals(basis_size)= Quantum number l for each basis function
!!    %rad_step= Step corresponding to radial mesh
!!    %sph_meshsz= Dimension of radial mesh for PAW spheres
!!
!! OUTPUT
!!  pawarray
!!    %kij(lmn2_size)= Kinetic overlap operator
!!
!! PARENTS
!!      atompaw2abinit
!!
!! CHILDRENN
!!      csimp,nderiv
!!
!! SOURCE

 subroutine calc_kij(pawarray,pawdata,pawps,pshead)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ---------------------------------------------
 type(pawarray_type) :: pawarray
 type(pawdata_type)  :: pawdata
 type(pawps_type)    :: pawps
 type(pshead_type)   :: pshead

!Local variables ---------------------------------------
 integer :: ib,ilm,ilmn,iln,ir,jlm,jlmn,jln,j0lmn,klmn,ll,llp,meshsz
 real(dp) :: llp2,intg,tintg
 real(dp), allocatable :: chi(:,:),ff(:),tchi(:,:),tff(:),&
&                         y1(:),y2(:),ty1(:),ty2(:)

!--------------------------------------------------------

 meshsz=pshead%sph_meshsz

!First, compute |chi_i>=T|phi_i>
!---------------------------------
 allocate(chi(meshsz,pshead%basis_size),tchi(meshsz,pshead%basis_size))
 allocate(y1(meshsz),ty1(meshsz),y2(meshsz),ty2(meshsz))
 do ib=1,pshead%basis_size
  ll=pshead%orbitals(ib);llp=ll+1;llp2=two*dble(llp)
  y2 (2:meshsz)=pawps%phi (2:meshsz,ib)/pawdata%rad(2:meshsz)**llp
  ty2(2:meshsz)=pawps%tphi(2:meshsz,ib)/pawdata%rad(2:meshsz)**llp
  call nderiv(pshead%rad_step, y2(2:meshsz), y1(2:meshsz),meshsz-1)
  call nderiv(pshead%rad_step,ty2(2:meshsz),ty1(2:meshsz),meshsz-1)
  call nderiv(pshead%rad_step, y1(2:meshsz), y2(2:meshsz),meshsz-1)
  call nderiv(pshead%rad_step,ty1(2:meshsz),ty2(2:meshsz),meshsz-1)
  chi (2:meshsz,ib)=(pawdata%rad(2:meshsz)* y2(2:meshsz)+llp2* y1(2:meshsz))*pawdata%rad(2:meshsz)**ll
  tchi(2:meshsz,ib)=(pawdata%rad(2:meshsz)*ty2(2:meshsz)+llp2*ty1(2:meshsz))*pawdata%rad(2:meshsz)**ll
  call deducer0(chi,meshsz,pawdata%rad);call deducer0(tchi,meshsz,pawdata%rad)
 enddo
 deallocate(y1,ty1,y2,ty2)

!Now, compute calculate kij=<phi_i|T|phi_j>
!------------------------------------------
 allocate(ff(meshsz),tff(meshsz))
 pawarray%kij=zero
 do jlmn=1,pshead%lmn_size
  j0lmn=jlmn*(jlmn-1)/2
  jlm=pawdata%indlmn(4,jlmn);jln=pawdata%indlmn(5,jlmn)
  do ilmn=1,jlmn
   klmn=j0lmn+ilmn
   ilm=pawdata%indlmn(4,ilmn);iln=pawdata%indlmn(5,ilmn)
   if (jlm==ilm) then
    ff(:)=pawps%phi(:,iln)*chi(:,jln)
    call csimp(ff,meshsz,pshead%rad_step,intg)
    tff(:)=pawps%tphi(:,iln)*tchi(:,jln)
    call csimp(tff,meshsz,pshead%rad_step,tintg)
    pawarray%kij(klmn)=tintg-intg
   endif
  enddo
 enddo
 deallocate(ff,tff)

 deallocate(chi,tchi)

 pawarray%kij=pawarray%kij*0.5d0   ! Translate from Rydberg to Hartree

 end subroutine
!!***
