!{\src2tex{textfont=tt}}
!!****f* ABINIT/rdpawps1
!! NAME
!! rdpawps1
!! 
!! FUNCTION
!! Read the header of a PAW pseudopotential file generated by AtomPAW
!!
!! COPYRIGHT
!! Copyright (C) 1998-2005 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the 
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!! 
!! INPUTS
!!  filename(3)= input file names (atomicdata, density, potential)
!!  unit(3)= input unit numbers
!!
!! OUTPUT
!!  pshead
!!    %atomic_charge= Total atomic charge
!!    %basis_size= Number of elements for the paw nl basis
!!    %core_charge= Core charge
!!    %core_meshsz= Dimension of radial mesh for core density
!!    %lambda= Lambda in gaussian type g(r)
!!    %lmn_size= Number of elements for the paw basis
!!    %orbitals(basis_size)= Quantum number l for each basis function
!!    %proj_meshsz= Dimension of radial mesh for tproj
!!    %pspxc_atom= AtomPaw s code number for the exchange-correlation
!!    %rad_step= Step corresponding to radial mesh
!!    %rc_sph= Default PAW sphere radius
!!    %shape_type= Shape function type
!!    %sigma= Sigma for gaussian type g(r)
!!    %sph_meshsz= Dimension of radial mesh for phi, tphi ...
!!    %title= Title for pseudopotential
!!  version= version number for AtomPAW2Abinit
!!
!! PARENTS
!!      atompaw2abinit
!!
!! CHILDREN
!!
!! SOURCE

 subroutine rdpawps1(filename,pshead,funit,version)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ---------------------------------------------
 integer :: funit
 character*(fnlen) :: filename
 character*5 :: version
 type(pshead_type) :: pshead

!Local variables ---------------------------------------
 integer :: ib
 logical :: endfile
 character*(fnlen) :: line,readline,strg

! *************************************************************************

!Open the atomicdata file for reading
 open(unit=funit,file=filename,form='formatted',status='old')

!Start a reading loop
 endfile=.false.
 do while (.not.endfile)
   read(funit,'(a)',err=10,end=10) readline
   line=adjustl(readline);goto 20
10 line="";endfile=.true.
20 continue

!--Read TITLE
  if (line(1:8)=='ATOMTYPE') then
   read(unit=line(9:fnlen),fmt=*) strg
   write(unit=pshead%title,fmt='(4a)') &
&   "Paw atomic data for element ",trim(ADJUSTL(strg)),&
&   " - Generated by AtomPAW (N. Holzwarth) + AtomPAW2Abinit v",version
  endif

!--Read BASIS SIZE
  if (line(1:10)=='BASIS_SIZE') then
   read(unit=line(11:fnlen),fmt=*) pshead%basis_size
   if (pshead%basis_size>20) then
    write(6,'(a)') "Error in rdpawps1: basis size too large (>20) !"
    close(funit);stop
   endif
  endif

!--Read ORBITALS
  if (line(1:8)=='ORBITALS') then
   read(funit,'(a)',err=11,end=11) readline
   line=adjustl(readline);goto 21
11 write(6,'(a)') "Error in rdpawps1: error reading orbitals !"
   close(funit);stop
21 read(unit=line(1:fnlen),fmt=*) &
&      (pshead%orbitals(ib),ib=1,pshead%basis_size)
  endif

!--Read INITOCC  -- added by NAWH 1/23/06
  if (line(1:7)=='INITOCC') then
   read(funit,*) (pshead%occ(ib),ib=1,pshead%basis_size)
   read(funit,'(a)') readline     ! read 'END'  
  endif

!--Read RC
  if (line(1:2)=='RC') then
   read(unit=line(3:fnlen),fmt=*) pshead%rc_sph
  endif

!--Read MESH SIZE
  if (line(1:9)=='MESH_SIZE') then
   read(unit=line(10:fnlen),fmt=*) pshead%sph_meshsz
   pshead%proj_meshsz=4.d0*pshead%sph_meshsz
  endif

!--Read CORETAIL_POINTS
  if (line(1:15)=='CORETAIL_POINTS') then
   read(unit=line(16:fnlen),fmt=*) pshead%core_meshsz
  endif

!--Read MESH STEP
  if (line(1:9)=='MESH_STEP') &
&    read(unit=line(10:fnlen),fmt=*) pshead%rad_step

!--Read ATOMIC CHARGE
  if (line(1:13)=='ATOMIC_CHARGE') &
&    read(unit=line(14:fnlen),fmt=*) pshead%atomic_charge

!--Read CORE CHARGE
  if (line(1:11)=='CORE_CHARGE') &
&    read(unit=line(12:fnlen),fmt=*) pshead%core_charge

!--Read EXCHANGE-CORRELATION TYPE
  if (line(1:10)=='ATOMXCTYPE') then
   read(unit=line(11:fnlen),fmt=*) strg
   if (trim(ADJUSTL(strg))=="LDA-PW") then
    pshead%pspxc_atom=14
   elseif (trim(ADJUSTL(strg))=="GGA-PBE") then
    pshead%pspxc_atom=16
   else
    write(6,'(a)') "Error in rdpawps1: unknown XC type !"
    close(funit);stop
   endif
  endif

!--Read SHAPE TYPE
  if (line(1:10)=='SHAPE_TYPE') then
   read(unit=line(11:fnlen),fmt=*) strg
   if (trim(ADJUSTL(strg))=="exshape") then
    pshead%shape_type=1
   elseif (trim(ADJUSTL(strg))=="sinc2") then
    pshead%shape_type=2
    pshead%lambda=0;pshead%sigma=0.d0
   else
    write(6,'(a)') "Error in rdpawps1: unknown shape type !"
    close(funit);stop
   endif
  endif

!End of reading loop
 enddo

!Close the atomicdata file
 close(funit)

!Tests of consistency
 if (pshead%core_meshsz<pshead%sph_meshsz) then
  write(6,'(a)') "Error in rdpawps1:"
  write(6,'(a)') "   Mesh size for tcore density (CORETAIL_POINTS)"
  write(6,'(a)') "   must be greater or equal than MESH_SIZE !"
  stop
 endif
!Radius of PAW spheres
 if (abs(pshead%rc_sph-pshead%rad_step*dble(pshead%sph_meshsz-1))>tol8) then
  write(6,'(a)') "Error in rdpawps1:"
  write(6,'(a)') "   Radius for PAW spheres (RC)"
  write(6,'(a)') "   must be equal to R(MESH_SIZE) !"
  stop
 endif
 pshead%rc_sph=pshead%rad_step*dble(pshead%sph_meshsz-1)

!Here must compute lmn_size
 pshead%lmn_size=0
 do ib=1,pshead%basis_size
  pshead%lmn_size=pshead%lmn_size+2*pshead%orbitals(ib)+1
 enddo

 end subroutine
!!***
