!{\src2tex{textfont=tt}}
!!****f* ABINIT/rdpawps2
!! NAME
!! rdpawps2
!! 
!! FUNCTION
!! Read the body of a PAW pseudopotential file generated by AtomPAW
!! (the header must have been read before)
!!
!! COPYRIGHT
!! Copyright (C) 1998-2005 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  filename= input file name (atomicdata)
!!  funit= input unit number
!!  pshead
!!    %basis_size= Number of elements for the paw nl basis
!!    %core_meshsz= Dimension of radial mesh for core density
!!    %lmn_size= Number of elements for the paw basis
!!    %orbitals(basis_size)= Quantum number l for each basis function
!!    %proj_meshsz= Dimension of radial mesh for tproj
!!    %shape_type= Shape function type
!!    %sph_meshsz= Dimension of radial mesh for phi, tphi ...
!!  pawdata
!!    %indlmn(6,lmn_size)= Gives l,m,n,lm,ln,s for i=lmn
!!    %rad(max_meshsz)= Coordinates of the radial grid
!!   
!! OUTPUT
!!  pawarray
!!    %kij(lmn2_size)= Kinetic overlap operator
!!    %vbare(sph_meshsz)= bare local potential (part of VH(tnzc))
!!  pawps
!!    %coreden4pr2(core_meshsz)= Core density multiplied by 4Pi.r2
!!    %tcoreden4pr2(core_meshsz)= Pseudized core density multiplied by 4Pi.r2
!!    %phi(sph_meshsz,basis_size)= PAW atomic wavefunctions on the radial grid
!!    %tphi(sph_meshsz,basis_size)= PAW atomic pseudo-wavefunctions on the radial grid
!!    %tproj(proj_meshsz,basis_size)= PAW projectors on the radial grid
!!
!! SIDE EFFECTS
!!  pshead
!!    %lambda= Lambda in gaussian type g(r)
!!    %sigma= Sigma for gaussian type g(r)
!!
!! PARENTS
!!      atompaw2abinit
!!
!! CHILDREN
!!
!! SOURCE

 subroutine rdpawps2(filename,pawarray,pawdata,pawps,pshead,funit)

 use defs_basis
 use defs_pawps
 
 implicit none
 
!Arguments ---------------------------------------------
 integer :: funit
 character*(fnlen) :: filename
 type(pawarray_type) :: pawarray
 type(pawdata_type)  :: pawdata
 type(pawps_type)    :: pawps
 type(pshead_type)   :: pshead

!Local variables ---------------------------------------
 integer :: ib,ilmn,ilm,iln,ir1,ir2,ir,jlmn,jlm,jln,j0lmn,klmn,nkij
 logical :: found,endfile,corefound,tcorefound,kijfound,shapeffound,vbarefound
 logical :: vionfound
 integer,allocatable :: indkij(:,:)
 logical,allocatable :: phifound(:),tphifound(:),tprojfound(:)
 real(dp) :: sf1,sf2,r1,r2
 real(dp), allocatable :: kij(:),shapef(:)
 character*(fnlen) :: line,readline

!functions
 character*(20) :: stripcomment
 integer :: mkint

! *********************************************************************

! ==================================================
! ====== 1-READ  ATOMICDATA FILE FROM AtomPAW ======
! ==================================================

!Init some flags
 allocate(phifound(pshead%basis_size));phifound=.false.
 allocate(tphifound(pshead%basis_size));tphifound=.false.
 allocate(tprojfound(pshead%basis_size));tprojfound=.false.
 shapeffound=.true.;if (pshead%shape_type==1) shapeffound=.false.
 corefound=.false.;tcorefound=.false.;vbarefound=.false.;vionfound=.false.
 kijfound=.false.

!Open the atomicdata file for reading
 open(unit=funit,file=filename,form='formatted',status='old')

!Start a reading loop
 endfile=.false.
 do while (.not.endfile)
   read(funit,'(a)',err=10,end=10) readline
   line=adjustl(readline);goto 20
10 line="";endfile=.true.
20 continue

!--Read WAVE FUNCTIONS PHI
  if (line(1:4)=='PHI ') then
   read(unit=line(5:fnlen),fmt=*) ib
   if (ib>pshead%basis_size) then
    write(6,'(a)') "Error in rdpawps2: PHI(ib) for ib>basis_sz !"
    close(funit);stop
   endif
   read(funit,*) (pawps%phi(ir,ib),ir=1,pshead%sph_meshsz)
   phifound(ib)=.true.
  endif

!--Read PSEUDO WAVE FUNCTIONS TPHI
  if (line(1:5)=='TPHI ') then
   read(unit=line(6:fnlen),fmt=*) ib
   if (ib>pshead%basis_size) then
    write(6,'(a)') "Error in rdpawps2: TPHI(ib) for ib>basis_sz !"
    close(funit);stop
   endif
   read(funit,*) (pawps%tphi(ir,ib),ir=1,pshead%sph_meshsz)
   tphifound(ib)=.true.
  endif

!--Read PROJECTORS TPROJ
  if (line(1:10)=='TPROJECTOR') then
   read(unit=line(11:fnlen),fmt=*) ib
   if (ib>pshead%basis_size) then
    write(6,'(a)') "Error in rdpawps2: TPROJ(ib) for ib>basis_sz !"
    close(funit);stop
   endif
   read(funit,*) (pawps%tproj(ir,ib),ir=1,pshead%sph_meshsz)
   tprojfound(ib)=.true.
  endif

!--Read core density CORE_DENSITY
  if (line(1:12)=='CORE_DENSITY') then
   read(funit,*) (pawps%coreden4pr2(ir),ir=1,pshead%sph_meshsz)
   corefound=.true.
  endif

!--Read pseudized core density CORETAIL_DENSITY
  if (line(1:16)=='CORETAIL_DENSITY') then
   read(funit,*) (pawps%tcoreden4pr2(ir),ir=1,pshead%core_meshsz)
   tcorefound=.true.
  endif

!--Read Vbare potential VLOCFUN     --no longer needed
  if (line(1:7)=='VLOCFUN') then
   read(funit,*) (pawarray%vbare(ir),ir=1,pshead%sph_meshsz)
   pawarray%vbare=pawarray%vbare*0.5d0
   vbarefound=.true.
  endif

!--Read Vbare potential VLOCION -- ionic local potentail with correct
!       unscreening of vxc   (vxc(tilde_core + tilde_n + hat_hat_n))
  if (line(1:7)=='VLOCION') then
     ir=mkint(trim(adjustl(stripcomment(line(8:)))))
     !write(*,*) 'vloc_meshxz = ', ir
     pshead%vloc_meshsz=ir
     if (size(pawps%vhtnzc)< ir) then
        deallocate(pawps%vhtnzc)
        allocate(pawps%vhtnzc(ir))
     endif
   read(funit,*) (pawps%vhtnzc(ir),ir=1,pshead%vloc_meshsz)
   pawps%vhtnzc=pawps%vhtnzc*0.5d0   ! change to Hartree units
   vionfound=.true.
  endif


!--Read EXPONENTIAL SHAPE FUNCTION
!  and  DEDUCE GAUSSIAN PARAMETERS
  if (pshead%shape_type==1.and.line(1:10)=='SHAPE_FUNC') then
   allocate(shapef(pshead%sph_meshsz))
   read(funit,*) (shapef(ir),ir=1,pshead%sph_meshsz)
   shapeffound=.true.
   ir1=pshead%sph_meshsz/2;ir2=3*pshead%sph_meshsz/4
   if (ir1==ir2) ir2=pshead%sph_meshsz
   r1=pawdata%rad(ir1);r2=pawdata%rad(ir2)
   sf1=shapef(ir1);sf2=shapef(ir2)
   pshead%lambda=nint(log(log(sf1)/log(sf2))/log(r1/r2))
   pshead%sigma=r1/(-log(sf1))**(1.d0/dble(pshead%lambda))
   deallocate(shapef)
  endif

!--Read Kinetic term KINETIC_ENERGY_MATRIX
  if (line(1:21)=='KINETIC_ENERGY_MATRIX') then
   allocate(indkij(pshead%basis_size,pshead%basis_size));indkij(:,:)=0;nkij=0
   do jln=1,pshead%basis_size
    do iln=1,jln
     if (pshead%orbitals(iln)==pshead%orbitals(jln)) then
      nkij=nkij+1;indkij(iln,jln)=nkij
     endif
    enddo
   enddo
   allocate(kij(nkij));read(funit,*) kij(:)
   pawarray%kij=zero
   do jlmn=1,pshead%lmn_size
    j0lmn=jlmn*(jlmn-1)/2
    jlm=pawdata%indlmn(4,jlmn);jln=pawdata%indlmn(5,jlmn)
    do ilmn=1,jlmn
     klmn=j0lmn+ilmn
     ilm=pawdata%indlmn(4,ilmn);iln=pawdata%indlmn(5,ilmn)
     if (ilm==jlm) pawarray%kij(klmn)=half*kij(indkij(iln,jln))
    enddo
   enddo
   deallocate(indkij,kij);kijfound=.true.
  endif

!End of reading loop
 enddo

!Close the atomicdata file
 close(funit)

!Test flags: is anything OK ?
 do ib=1,pshead%basis_size
  if (.not.phifound(ib)) &
&  write(6,'(a,i2,a)') "Error in rdpawps2: PHI(",ib,") not found !"
  if (.not.tphifound(ib)) &
&  write(6,'(a,i2,a)') "Error in rdpawps2: TPHI(",ib,") not found !"
  if (.not.tprojfound(ib)) &
&  write(6,'(a,i2,a)') "Error in rdpawps2: TPROJ(",ib,") not found !"
 enddo
 if (.not.corefound) &
&  write(6,'(a,i2,a)') "Error in rdpawps2: CORE DENSITY not found !"
 if (.not.tcorefound) &
&  write(6,'(a,i2,a)') "Error in rdpawps2: CORETAIL DENSITY not found !"
 if (.not.kijfound) &
&  write(6,'(a,i2,a)') "Error in rdpawps2: KINETIC ENERGY MATRIX not found !"
! if (.not.vbarefound) &
!&  write(6,'(a,i2,a)') "Error in rdpawps2: VLOC FUNC not found !"
 if (.not.vionfound) &
&  write(6,'(a,i2,a)') "Error in rdpawps2: VLOC ION FUNC not found !"
 if (.not.shapeffound) &
&  write(6,'(a,i2,a)') "Error in rdpawps2: SHAPE FUNC not found !"
! found=corefound.and.tcorefound.and.kijfound.and.vbarefound.and.shapeffound
 found=corefound.and.tcorefound.and.kijfound.and.vionfound.and.shapeffound
 do ib=1,pshead%basis_size
  found=found.and.phifound(ib).and.tphifound(ib).and.tprojfound(ib)
 enddo
 if (.not.found) stop
 deallocate(phifound,tphifound,tprojfound)

!===========================================================
!Copy pseudized core density to core density outside spheres
 if (pshead%core_meshsz>pshead%sph_meshsz) &
&  pawps%coreden4pr2(pshead%sph_meshsz+1:pshead%core_meshsz) = &
&  pawps%tcoreden4pr2(pshead%sph_meshsz+1:pshead%core_meshsz)

 end subroutine
!!***
